@@ -295,7 +295,7 @@ NULL
 #'
 #' *Reference for local trends:*
 #'
-#' Barnett, L.A.K., E.J. Ward, S.C. Anderson. Improving estimates of species
+#' Barnett, L.A.K., E.J. Ward, S.C. Anderson. 2021. Improving estimates of species
 #' distribution change by incorporating local trends. Ecography. 44(3):427-439.
 #' \doi{10.1111/ecog.05176}.
 #'
@@ -311,14 +311,14 @@ NULL
 #' *Discussion of and illustration of some decision points when fitting these
 #' models:*
 #'
-#' Commander, C.J.C., Barnett, L.A.K., Ward, E.J., Anderson, S.C., and
-#' Essington, T.E. 2022. The shadow model: how and why small choices in
+#' Commander, C.J.C., L.A.K. Barnett, E.J. Ward, S.C. Anderson, T.E.
+#' Essington. 2022. The shadow model: how and why small choices in
 #' spatially explicit species distribution models affect predictions. PeerJ 10:
 #' e12783. \doi{10.7717/peerj.12783}.
 #'
 #' *Application and description of threshold/break-point models:*
 #'
-#' Essington, T.E. S.C. Anderson, L.A.K. Barnett, H.M. Berger, S.A. Siedlecki,
+#' Essington, T.E., S.C. Anderson, L.A.K. Barnett, H.M. Berger, S.A. Siedlecki,
 #' E.J. Ward. 2022. Advancing statistical models to reveal the effect of
 #' dissolved oxygen on the spatial distribution of marine taxa using thresholds
 #' and a physiologically based index. Ecography. 2022: e06249
@@ -333,7 +333,7 @@ NULL
 #' *Several sections of the original TMB model code were adapted from the
 #' VAST R package:*
 #'
-#' Thorson, J.T., 2019. Guidance for decisions using the Vector Autoregressive
+#' Thorson, J.T. 2019. Guidance for decisions using the Vector Autoregressive
 #' Spatio-Temporal (VAST) package in stock, ecosystem, habitat and climate
 #' assessments. Fish. Res. 210:143–161.
 #' \doi{10.1016/j.fishres.2018.10.013}.
@@ -343,16 +343,16 @@ NULL
 #' idea behind the TMB prediction approach were adapted from the glmmTMB R
 #' package:*
 #'
-#' Mollie E. Brooks, Kasper Kristensen, Koen J. van Benthem, Arni Magnusson,
-#' Casper W. Berg, Anders Nielsen, Hans J. Skaug, Martin Maechler and Benjamin
-#' M. Bolker (2017). glmmTMB Balances Speed and Flexibility Among Packages for
+#' Brooks, M.E., K. Kristensen, K.J. van Benthem, A. Magnusson,
+#' C.W. Berg, A. Nielsen, H.J. Skaug, M. Maechler, B.M. Bolker.
+#'  2017. glmmTMB Balances Speed and Flexibility Among Packages for
 #' Zero-inflated Generalized Linear Mixed Modeling. The R Journal, 9(2):378-400.
 #' \doi{10.32614/rj-2017-066}.
 #'
 #' *Implementation of geometric anisotropy with the SPDE and use of random
 #' field GLMMs for index standardization*:
 #'
-#' Thorson, J.T., Shelton, A.O., Ward, E.J., and Skaug, H.J. 2015.
+#' Thorson, J.T., A.O. Shelton, E.J. Ward, H.J. Skaug. 2015.
 #' Geostatistical delta-generalized linear mixed models improve precision for
 #' estimated abundance indices for West Coast groundfishes. ICES J. Mar. Sci.
 #' 72(5): 1297–1310. \doi{10.1093/icesjms/fsu243}.
@@ -701,14 +701,16 @@ sdmTMB <- function(
   assert_that(class(formula) %in% c("formula", "list"))
   assert_that(inherits(data, "data.frame"))
   time_varying_type <- match.arg(time_varying_type)
-  if (!is.null(map) && length(map) != length(start)) {
-    cli_warn(c("`length(map) != length(start)`.",
-      "You likely want to specify `start` values if you are setting the `map` argument."))
-  }
+  # if (!is.null(map) && length(map) != length(start)) {
+  #   cli_warn(c("`length(map) != length(start)`.",
+  #     "You likely want to specify `start` values if you are setting the `map` argument."))
+  # }
 
   if (!is.null(time)) {
     assert_that(time %in% names(data),
       msg = "Specified `time` column is missing from `data`.")
+    assert_that(sum(is.na(as.numeric(data[[time]]))) == 0L,
+      msg = "Specified `time` column can't be coerced to a numeric value or contains NAs. Please remove any NAs in the time column.")
   }
   if (is.null(time)) {
     time <- "_sdmTMB_time"
@@ -765,14 +767,14 @@ sdmTMB <- function(
   }
 
   if (!is.null(extra_time)) { # for forecasting or interpolating
-    data <- expand_time(df = data, time_slices = extra_time, time_column = time, weights = weights, offset = offset, upr = upr)
-    if (!is.null(offset)) offset <- data[["__sdmTMB_offset__"]] # expanded
-    if (!is.null(weights)) weights <- data[["__weight_sdmTMB__"]] # expanded
-    if (!is.null(upr)) upr <- data[["__dcens_upr__"]] # expanded
-    data[["__dcens_upr__"]] <- NULL
+    data <- expand_time(df = data, time_slices = extra_time, time_column = time,
+      weights = weights, offset = offset, upr = upr)
+    offset <- data[["__sdmTMB_offset__"]] # expanded
+    weights <- data[["__weight_sdmTMB__"]] # expanded
+    upr <- data[["__dcens_upr__"]] # expanded
     spde$loc_xy <- as.matrix(data[,spde$xy_cols,drop=FALSE])
     spde$A_st <- fmesher::fm_basis(spde$mesh, loc = spde$loc_xy)
-    spde$sdm_spatial_id <- seq(1, nrow(data)) # FIXME
+    spde$sdm_spatial_id <- seq(1, nrow(data)) # FIXME?
   }
   check_irregalar_time(data, time, spatiotemporal, time_varying)
 
@@ -797,8 +799,10 @@ sdmTMB <- function(
     .int <- grep("(Intercept)", colnames(z_i))
     if (sum(.int) > 0) z_i <- z_i[,-.int,drop=FALSE]
     spatial_varying <- colnames(z_i)
+    svc_contrasts <- attr(z_i, which = "contrasts")
   } else {
     z_i <- matrix(0, nrow(data), 0L)
+    svc_contrasts <- NULL
   }
   n_z <- ncol(z_i)
 
@@ -1347,10 +1351,11 @@ sdmTMB <- function(
     cli_abort("Profile not yet working with delta models.")
 
   for (i in seq_along(map)) { # user supplied
-    cli_inform(c(i = paste0("Fixing (mapping) `", names(map)[i],
-      "` at specified starting value(s) of:"),
-      paste0("  ",
-        paste(round(tmb_params[[names(map)[i]]], 3), collapse = ", "))))
+    cli_inform(c(i = paste0("Fixing or mirroring `", names(map)[i], "`")))
+    # ,
+    #   "` at specified starting value(s) of:"),
+    #   paste0("  ",
+    #     paste(round(tmb_params[[names(map)[i]]], 3), collapse = ", "))))
   }
   tmb_map <- c(map, tmb_map) # add user-supplied mapping
 
