@@ -145,6 +145,11 @@ extractAIC.sdmTMB <- function(fit, scale, k = 2, ...) {
 #' @importFrom stats family
 #' @export
 family.sdmTMB <- function (object, ...) {
+  if (.has_delta_attr(object)) {
+    which_model <- attr(object, "delta_model_predict")
+    if (is.na(which_model)) which_model <- 2L # combined; for link
+    return(object$family[[which_model]])
+  }
   if ("visreg_model" %in% names(object)) {
     return(object$family[[object$visreg_model]])
   } else {
@@ -184,8 +189,20 @@ df.residual.sdmTMB <- function(object, ...) {
   nobs(object) - length(object$model$par)
 }
 
+.has_delta_attr <- function(x) {
+  "delta_model_predict" %in% names(attributes(x))
+}
+
 #' @export
 formula.sdmTMB <- function (x, ...) {
+  if (.has_delta_attr(x)) {
+    which_model <- attr(x, "delta_model_predict")
+    if (!identical(x$formula[[1]], x$formula[[2]]) && is.na(which_model)) {
+      cli_abort("Delta component formulas are not the same but ggeffects::ggpredict() is trying to predict on the combined model. For now, predict on one or the other component, or keep the formulas the same, or write your own prediction and plot code.")
+    }
+    if (is.na(which_model)) which_model <- 1L # combined take 1!?
+    return(x$formula[[which_model]])
+  }
   if (length(x$formula) > 1L) {
     if ("visreg_model" %in% names(x)) {
       return(x$formula[[x$visreg_model]])
@@ -233,6 +250,12 @@ Effect.sdmTMB <- function(focal.predictors, mod, ...) {
     cli_abort("Please install the effects package")
   }
 
+  if (is_delta(mod)) {
+    msg <- paste0("Effect() and ggeffects::ggeffect() do not yet work with ",
+      "sdmTMB delta/hurdle models. Please use ggeffects::ggpredict() instead.")
+    cli_abort(msg)
+  }
+
   vc <- vcov(mod)
   b <- tidy(mod, silent = TRUE)
 
